@@ -71,8 +71,9 @@ bool extHardSetLabel();
  */
 
 ExtRegion *
-extLabFirst(tile, arg)
+extLabFirst(tile, dinfo, arg)
     Tile *tile;
+    TileType dinfo;	/* (unused) */
     FindRegion *arg;
 {
     TransRegion *reg;
@@ -82,6 +83,11 @@ extLabFirst(tile, arg)
     reg->treg_pnum = DBNumPlanes;
     reg->treg_area = DBNumPlanes;
     reg->treg_tile = tile;
+    reg->treg_dinfo = dinfo;
+
+    /* Setting treg_pnum to DBNumPlanes ensures that treg_ll and treg_type
+     * will be set for identifying the node when extSetNodeNum() is called.
+     */
 
     /* Prepend it to the region list */
     reg->treg_next = (TransRegion *) arg->fra_region;
@@ -91,25 +97,16 @@ extLabFirst(tile, arg)
 
     /*ARGSUSED*/
 int
-extLabEach(tile, pNum, arg)
+extLabEach(tile, dinfo, pNum, arg)
     Tile *tile;
+    TileType dinfo;	/* (unused) */
     int pNum;
     FindRegion *arg;
 {
-
-    /* Avoid setting the region's tile pointer to a split tile if we can */
-    /*
-    if (IsSplit(reg->treg_tile) && !IsSplit(tile))
-    {
-	reg->treg_tile = tile;
-	reg->treg_area = pNum;
-    }
-    */
-
     TransRegion *reg = (TransRegion *) arg->fra_region;
 
     if (reg->treg_area == DBNumPlanes) reg->treg_area = pNum;
-    extSetNodeNum((LabRegion *)reg, pNum, tile);
+    extSetNodeNum((LabRegion *)reg, pNum, tile, dinfo);
     return (0);
 }
 
@@ -172,7 +169,7 @@ extHardProc(scx, arg)
     CellDef *def = scx->scx_use->cu_def;
     TransRegion *reg;
     TransRegion *labRegList;
-    LabelList *subList;
+    LabelList *subList = NULL;
     char *savenext;
     int ret = 0;
 
@@ -203,7 +200,7 @@ extHardProc(scx, arg)
      * single child.
      */
     labRegList = (TransRegion *) ExtFindRegions(def, &scx->scx_area,
-		    &arg->hw_mask, ExtCurStyle->exts_nodeConn, extUnInit,
+		    &arg->hw_mask, ExtCurStyle->exts_nodeConn,
 		    extLabFirst, extLabEach);
     if (labRegList)
     {
@@ -240,7 +237,8 @@ extHardProc(scx, arg)
 	 */
 	if (ExtCurStyle->exts_globSubstrateDefaultType != -1)
 	    for (reg = labRegList; reg; reg = reg->treg_next)
-		if (TTMaskHasType(&ExtCurStyle->exts_globSubstrateTypes, reg->treg_type))
+		if (TTMaskHasType(&ExtCurStyle->exts_globSubstrateTypes,
+				reg->treg_type & TT_LEFTMASK))
 		    if (reg->treg_pnum != ExtCurStyle->exts_globSubstratePlane)
 		    {
 			reg->treg_labels = subList;
@@ -261,6 +259,7 @@ extHardProc(scx, arg)
     goto done;
 
 success:
+    if (subList != NULL) freeMagic(subList);
     extHardFreeAll(def, labRegList);
     ret = 1;
 
@@ -338,7 +337,7 @@ extHardSetLabel(scx, reg, arg)
 	 tp = PlaneGetHint(scx->scx_use->cu_def->cd_planes[pNum]);
 	 GOTOPOINT(tp, &r.r_ll);
 	 PlaneSetHint(scx->scx_use->cu_def->cd_planes[pNum], tp);
-	 if ((TransRegion *)extGetRegion(tp) == reg)
+	 if ((TransRegion *)ExtGetRegion(tp, (TileType)0) == reg)
 	 {
 	      /* found an OK point */
 	      r.r_ur.p_x =r.r_ll.p_x+1;
@@ -347,7 +346,7 @@ extHardSetLabel(scx, reg, arg)
 	 else
 	 {
 	      GOTOPOINT(tp, &r.r_ur);
-	      if ((TransRegion *)extGetRegion(tp) == reg)
+	      if ((TransRegion *)ExtGetRegion(tp, (TileType)0) == reg)
 	      {
 	      	   r.r_ll = r.r_ur;
 	      }
@@ -493,17 +492,17 @@ extHardFreeAll(def, tReg)
     arg.fra_connectsTo = ExtCurStyle->exts_nodeConn;
     arg.fra_def = def;
     arg.fra_each = (int (*)()) NULL;
-    arg.fra_region = (ExtRegion *) extUnInit;
+    arg.fra_region = (ExtRegion *) CLIENTDEFAULT;
 
     free_magic1_t mm1 = freeMagic1_init();
     for (reg = tReg; reg; reg = reg->treg_next)
     {
-	/* Reset all ti_client fields to extUnInit */
+	/* Reset all ti_client fields to CLIENTDEFAULT */
 	arg.fra_uninit = (ClientData) reg;
 	if (reg->treg_tile)
 	{
 	    arg.fra_pNum = reg->treg_area;
-	    ExtFindNeighbors(reg->treg_tile, arg.fra_pNum, &arg);
+	    ExtFindNeighbors(reg->treg_tile, reg->treg_dinfo, arg.fra_pNum, &arg);
 	}
 
 	/* Free all LabelLists and then the region */
