@@ -257,7 +257,7 @@ groglSetCharSize (size)
  *	Determine the size of a text string.
  *
  * Results:
- *	0 on success.  -1 on error (no side-effects).
+ *	Returns 0 when 'r' updated, otherwise -1 on error (no side-effects).
  *
  * Side effects:
  *	A rectangle is filled in that is the size of the text in pixels.
@@ -573,7 +573,7 @@ groglCreateBackingStore(MagWindow *w)
     if (w->w_client != DBWclientID) return;
 
     /* deferred */
-    if (w->w_grdata == (Window)NULL) return;
+    if (w->w_grdata == PTR2CD(NULL)) return;
 
     width = w->w_screenArea.r_xtop - w->w_screenArea.r_xbot;
     height = w->w_screenArea.r_ytop - w->w_screenArea.r_ybot;
